#
# rfc822BlogTimeZone  -  A Movable Type Plug-In
# by John Gruber
# http://daringfireball.net
#
# Version 1.0
# Tue Oct 22, 2002
#
# See readme and POD for details and installation instructions.
#
# Copyright (c) 2002 John Gruber
#
# This program is free and open software. You may use, copy, modify,
# distribute, and sell this program (and any modified variants) in any
# way you wish, provided you do not restrict others from doing the same.
#

use MT::Template::Context;

MT::Template::Context->add_tag( rfc822BlogTimeZone => sub {
    my $so = $_[0]->stash('blog')->server_offset;
    sprintf "%s%02d00", $so < 0 ? '-' : '+', abs($so);
});

1;
__END__


=pod

=head1 NAME

B<rfc822BlogTimeZone> - A Movable Type plug-in.


=head1 DESCRIPTION

This plug-in allows you to use a new Movable Type template tag, C<< <$MTrfc822BlogTimeZone$> >>, which inserts your blog's timezone displayed as an offset from UTC in C<+|-hhmm> format. This is very similar to Movable Type's built-in C<< <$MTBlogTimeZone$> >> tag, with the difference that C<< <$MTrfc822BlogTimeZone$> >> does I<not> include a colon between the hour and minute.

For example, C<< <$MTrfc822BlogTimeZone$> >> produces output like this:

	-0500

Whereas C<< <$MTBlogTimeZone$> >> produces output like this:

	-05:00

C<< <$MTrfc822BlogTimeZone$> >> is useful when generating RFC-822-compliant date strings. For example, the following Movable Type template code:

    <MTEntries lastn="1">
    <$MTEntryDate format="%a, %d %b %Y %H:%M:%S"$><$MTrfc822BlogTimeZone$>
    </MTEntries>

will produce an RFC-822 date in the following format:

    Mon, 21 Oct 2002 14:04:23 -0500

This is particularly useful when creating RSS 0.91 feeds. RSS 0.91 requires date strings to comply with RFC-822; Movable Type's default RSS 0.91 template does not produce RFC-822-compliant dates. In the grand scheme of things, this doesn't really matter, but if you wish to experience the warm, tingly sensation of your RSS 0.91 feed passing through Mark Pilgrim and Sam Ruby's online RSS Validator (see below for link), this is useful.


=head1 INSTALLATION

=over 4

=item 1.

Copy the "rfc822BlogTimeZone.pl" file into your Movable Type "plugins" directory. The "plugins" folder should be in the same directory as "mt.cgi"; if it doesn't already exist, use your FTP program to create it. Your installation should look like this:

	(mt home)/plugins/rfc822BlogTimeZone.pl

=item 2.

Set the permissions on "rfc822BlogTimeZone.pl" to 755.

=item 3.

If you're currently logged in to Movable Type, log out and log back in. 

=item 4.

That's it. You can now call this plugin by including the following tag in your templates:

	<$MTrfc822BlogTimeZone$>


=back


=head1 OPTIONS

None.


=head1 SEE ALSO

RFC-822:

	http://www.faqs.org/rfcs/rfc822.html

RSS Validator:

	http://feeds.archive.org/validator/

Movable Type:

	http://movabletype.org/

=head1 VERSION HISTORY

    1.0: Tue Oct 22, 2002
    Initial release.


=head1 CREDITS

This plug-in is based on Movable Type's internal C<< <$MTBlogTimeZone$> >> tag, which is copyright 2001-2002 Benjamin Trott.


=head1 COPYRIGHT and LICENSE

Copyright (c) 2002 John Gruber C<< <http://daringfireball.net/> >>

This program is free and open software. You may use, copy, modify, distribute,
and sell this program (and any modified variants) in any way you wish,
provided you do not restrict others from doing the same.

=cut
